summaryrefslogtreecommitdiff
path: root/dbaccess/source/ui/dlg
diff options
context:
space:
mode:
Diffstat (limited to 'dbaccess/source/ui/dlg')
-rw-r--r--dbaccess/source/ui/dlg/AdabasStat.cxx4
-rw-r--r--dbaccess/source/ui/dlg/CollectionView.cxx4
-rw-r--r--dbaccess/source/ui/dlg/ConnectionHelper.cxx2
-rw-r--r--dbaccess/source/ui/dlg/ConnectionPage.cxx6
-rw-r--r--dbaccess/source/ui/dlg/ConnectionPage.hxx2
-rw-r--r--dbaccess/source/ui/dlg/ConnectionPageSetup.cxx2
-rw-r--r--dbaccess/source/ui/dlg/ConnectionPageSetup.hxx4
-rw-r--r--dbaccess/source/ui/dlg/DBSetupConnectionPages.cxx10
-rw-r--r--dbaccess/source/ui/dlg/DBSetupConnectionPages.hxx32
-rw-r--r--[-rwxr-xr-x]dbaccess/source/ui/dlg/DbAdminImpl.cxx8
-rw-r--r--dbaccess/source/ui/dlg/DriverSettings.cxx2
-rw-r--r--dbaccess/source/ui/dlg/RelationDlg.cxx26
-rw-r--r--dbaccess/source/ui/dlg/UserAdminDlg.cxx2
-rwxr-xr-xdbaccess/source/ui/dlg/admincontrols.cxx6
-rwxr-xr-xdbaccess/source/ui/dlg/admincontrols.hxx2
-rw-r--r--dbaccess/source/ui/dlg/adminpages.cxx10
-rw-r--r--dbaccess/source/ui/dlg/adminpages.hxx8
-rw-r--r--dbaccess/source/ui/dlg/adodatalinks.cxx2
-rw-r--r--dbaccess/source/ui/dlg/adodatalinks.hxx2
-rw-r--r--dbaccess/source/ui/dlg/adtabdlg.cxx14
-rw-r--r--dbaccess/source/ui/dlg/advancedsettings.cxx18
-rw-r--r--dbaccess/source/ui/dlg/advancedsettings.hxx4
-rw-r--r--dbaccess/source/ui/dlg/dbadmin.cxx4
-rw-r--r--dbaccess/source/ui/dlg/dbfindex.hxx2
-rw-r--r--dbaccess/source/ui/dlg/dbwiz.cxx2
-rw-r--r--dbaccess/source/ui/dlg/detailpages.cxx14
-rw-r--r--dbaccess/source/ui/dlg/detailpages.hxx28
-rw-r--r--dbaccess/source/ui/dlg/directsql.cxx4
-rw-r--r--dbaccess/source/ui/dlg/dlgattr.cxx4
-rw-r--r--dbaccess/source/ui/dlg/dlgsave.cxx6
-rw-r--r--dbaccess/source/ui/dlg/dlgsize.src11
-rw-r--r--dbaccess/source/ui/dlg/dsselect.cxx6
-rw-r--r--dbaccess/source/ui/dlg/dsselect.hxx2
-rw-r--r--dbaccess/source/ui/dlg/generalpage.cxx4
-rw-r--r--dbaccess/source/ui/dlg/generalpage.hxx2
-rw-r--r--dbaccess/source/ui/dlg/queryorder.cxx2
-rw-r--r--dbaccess/source/ui/dlg/sqlmessage.cxx16
-rw-r--r--dbaccess/source/ui/dlg/tablespage.cxx2
-rw-r--r--dbaccess/source/ui/dlg/tablespage.hxx4
39 files changed, 136 insertions, 147 deletions
diff --git a/dbaccess/source/ui/dlg/AdabasStat.cxx b/dbaccess/source/ui/dlg/AdabasStat.cxx
index a17de64c5891..7dd769be3131 100644
--- a/dbaccess/source/ui/dlg/AdabasStat.cxx
+++ b/dbaccess/source/ui/dlg/AdabasStat.cxx
@@ -148,8 +148,8 @@ OAdabasStatistics::OAdabasStatistics( Window* pParent,
double nUsedPages = xRow->getInt(1) / 256;
double nFreePages = xRow->getInt(2) / 256;
- m_ET_SIZE.SetText(::rtl::OUString::valueOf((INT32)nUsedPages));
- m_ET_FREESIZE.SetText(::rtl::OUString::valueOf((INT32)nFreePages));
+ m_ET_SIZE.SetText(::rtl::OUString::valueOf((sal_Int32)nUsedPages));
+ m_ET_FREESIZE.SetText(::rtl::OUString::valueOf((sal_Int32)nFreePages));
m_ET_MEMORYUSING.SetValue(static_cast<sal_Int32>(((nUsedPages-nFreePages)/nUsedPages)*100));
}
else
diff --git a/dbaccess/source/ui/dlg/CollectionView.cxx b/dbaccess/source/ui/dlg/CollectionView.cxx
index f9762833641e..a8609d03348d 100644
--- a/dbaccess/source/ui/dlg/CollectionView.cxx
+++ b/dbaccess/source/ui/dlg/CollectionView.cxx
@@ -271,7 +271,7 @@ IMPL_LINK( OCollectionView, Save_Click, PushButton*, EMPTYARG )
// xNameContainer->removeByName(sName);
}
m_aName.SetText(sName);
- EndDialog( TRUE );
+ EndDialog( sal_True );
}
}
catch( const Exception& )
@@ -358,7 +358,7 @@ IMPL_LINK( OCollectionView, Dbl_Click_FileView, SvtFileView*, EMPTYARG )
// -----------------------------------------------------------------------------
void OCollectionView::initCurrentPath()
{
- BOOL bEnable = FALSE;
+ sal_Bool bEnable = sal_False;
try
{
if ( m_xContent.is() )
diff --git a/dbaccess/source/ui/dlg/ConnectionHelper.cxx b/dbaccess/source/ui/dlg/ConnectionHelper.cxx
index 7eae4fa04953..bf746e0243d3 100644
--- a/dbaccess/source/ui/dlg/ConnectionHelper.cxx
+++ b/dbaccess/source/ui/dlg/ConnectionHelper.cxx
@@ -226,7 +226,7 @@ DBG_NAME(OConnectionHelper)
m_aConnectionURL.Show();
m_aConnectionURL.ShowPrefix( ::dbaccess::DST_JDBC == m_pCollection->determineType(m_eType) );
- BOOL bEnableBrowseButton = m_pCollection->supportsBrowsing( m_eType );
+ sal_Bool bEnableBrowseButton = m_pCollection->supportsBrowsing( m_eType );
m_aPB_Connection.Show( bEnableBrowseButton );
SFX_ITEMSET_GET(_rSet, pUrlItem, SfxStringItem, DSID_CONNECTURL, sal_True);
diff --git a/dbaccess/source/ui/dlg/ConnectionPage.cxx b/dbaccess/source/ui/dlg/ConnectionPage.cxx
index a1a146cd7b4b..a221eee9c371 100644
--- a/dbaccess/source/ui/dlg/ConnectionPage.cxx
+++ b/dbaccess/source/ui/dlg/ConnectionPage.cxx
@@ -346,7 +346,7 @@ namespace dbaui
String sUrl = pUrlItem->GetValue();
setURL( sUrl );
- const BOOL bEnableJDBC = m_pCollection->determineType(m_eType) == ::dbaccess::DST_JDBC;
+ const sal_Bool bEnableJDBC = m_pCollection->determineType(m_eType) == ::dbaccess::DST_JDBC;
if ( !pJdbcDrvItem->GetValue().Len() )
{
String sDefaultJdbcDriverName = m_pCollection->getJavaDriverClass(m_eType);
@@ -436,7 +436,7 @@ namespace dbaui
{
}
- USHORT nMessage = bSuccess ? STR_JDBCDRIVER_SUCCESS : STR_JDBCDRIVER_NO_SUCCESS;
+ sal_uInt16 nMessage = bSuccess ? STR_JDBCDRIVER_SUCCESS : STR_JDBCDRIVER_NO_SUCCESS;
OSQLMessageBox aMsg( this, String( ModuleRes( nMessage ) ), String() );
aMsg.Execute();
return 0L;
@@ -445,7 +445,7 @@ namespace dbaui
bool OConnectionTabPage::checkTestConnection()
{
OSL_ENSURE(m_pAdminDialog,"No Admin dialog set! ->GPF");
- BOOL bEnableTestConnection = !m_aConnectionURL.IsVisible() || (m_aConnectionURL.GetTextNoPrefix().Len() != 0);
+ sal_Bool bEnableTestConnection = !m_aConnectionURL.IsVisible() || (m_aConnectionURL.GetTextNoPrefix().Len() != 0);
if ( m_pCollection->determineType(m_eType) == ::dbaccess::DST_JDBC )
bEnableTestConnection = bEnableTestConnection && (m_aJavaDriver.GetText().Len() != 0);
m_aTestConnection.Enable(bEnableTestConnection);
diff --git a/dbaccess/source/ui/dlg/ConnectionPage.hxx b/dbaccess/source/ui/dlg/ConnectionPage.hxx
index 2d6fef74c598..6406b9547427 100644
--- a/dbaccess/source/ui/dlg/ConnectionPage.hxx
+++ b/dbaccess/source/ui/dlg/ConnectionPage.hxx
@@ -81,7 +81,7 @@ namespace dbaui
public:
static SfxTabPage* Create( Window* pParent, const SfxItemSet& _rAttrSet );
- virtual BOOL FillItemSet (SfxItemSet& _rCoreAttrs);
+ virtual sal_Bool FillItemSet (SfxItemSet& _rCoreAttrs);
virtual void implInitControls(const SfxItemSet& _rSet, sal_Bool _bSaveValue);
diff --git a/dbaccess/source/ui/dlg/ConnectionPageSetup.cxx b/dbaccess/source/ui/dlg/ConnectionPageSetup.cxx
index f53054d37339..f739913850b5 100644
--- a/dbaccess/source/ui/dlg/ConnectionPageSetup.cxx
+++ b/dbaccess/source/ui/dlg/ConnectionPageSetup.cxx
@@ -211,7 +211,7 @@ namespace dbaui
//= OConnectionTabPageSetup
//========================================================================
DBG_NAME(OConnectionTabPageSetup)
- OConnectionTabPageSetup::OConnectionTabPageSetup(Window* pParent, USHORT _rId, const SfxItemSet& _rCoreAttrs, USHORT _nHelpTextResId, USHORT _nHeaderResId, USHORT _nUrlResId)
+ OConnectionTabPageSetup::OConnectionTabPageSetup(Window* pParent, sal_uInt16 _rId, const SfxItemSet& _rCoreAttrs, sal_uInt16 _nHelpTextResId, sal_uInt16 _nHeaderResId, sal_uInt16 _nUrlResId)
:OConnectionHelper(pParent, ModuleRes(_rId), _rCoreAttrs)
,m_bUserGrabFocus(sal_True)
,m_aFT_HelpText(this, ModuleRes(FT_AUTOWIZARDHELPTEXT))
diff --git a/dbaccess/source/ui/dlg/ConnectionPageSetup.hxx b/dbaccess/source/ui/dlg/ConnectionPageSetup.hxx
index 79a16c880c54..01f25b1ac175 100644
--- a/dbaccess/source/ui/dlg/ConnectionPageSetup.hxx
+++ b/dbaccess/source/ui/dlg/ConnectionPageSetup.hxx
@@ -86,7 +86,7 @@ namespace dbaui
static OGenericAdministrationPage* CreateUserDefinedTabPage( Window* pParent, const SfxItemSet& _rAttrSet );
- virtual BOOL FillItemSet (SfxItemSet& _rCoreAttrs);
+ virtual sal_Bool FillItemSet (SfxItemSet& _rCoreAttrs);
virtual void implInitControls(const SfxItemSet& _rSet, sal_Bool _bSaveValue);
virtual sal_Bool commitPage( ::svt::WizardTypes::CommitPageReason _eReason );
@@ -104,7 +104,7 @@ namespace dbaui
protected:
- OConnectionTabPageSetup(Window* pParent, USHORT _rId, const SfxItemSet& _rCoreAttrs, USHORT _nHelpTextResId, USHORT _nHeaderResId, USHORT _nUrlResId);
+ OConnectionTabPageSetup(Window* pParent, sal_uInt16 _rId, const SfxItemSet& _rCoreAttrs, sal_uInt16 _nHelpTextResId, sal_uInt16 _nHeaderResId, sal_uInt16 _nUrlResId);
virtual bool checkTestConnection();
// nControlFlags ist eine Kombination der CBTP_xxx-Konstanten
virtual ~OConnectionTabPageSetup();
diff --git a/dbaccess/source/ui/dlg/DBSetupConnectionPages.cxx b/dbaccess/source/ui/dlg/DBSetupConnectionPages.cxx
index cfc3deda1149..b8d9d2fb77e3 100644
--- a/dbaccess/source/ui/dlg/DBSetupConnectionPages.cxx
+++ b/dbaccess/source/ui/dlg/DBSetupConnectionPages.cxx
@@ -385,7 +385,7 @@ DBG_NAME(OMySQLIntroPageSetup)
// -----------------------------------------------------------------------
- BOOL OMySQLIntroPageSetup::FillItemSet(SfxItemSet& /*_rSet*/)
+ sal_Bool OMySQLIntroPageSetup::FillItemSet(SfxItemSet& /*_rSet*/)
{
OSL_ENSURE(sal_False,"Who called me?! Please ask oj for more information.");
return sal_True;
@@ -473,7 +473,7 @@ DBG_NAME(OMySQLIntroPageSetup)
//========================================================================
//= OMySQLJDBCConnectionPageSetup
//========================================================================
- OGeneralSpecialJDBCConnectionPageSetup::OGeneralSpecialJDBCConnectionPageSetup( Window* pParent,USHORT _nResId, const SfxItemSet& _rCoreAttrs ,USHORT _nPortId, USHORT _nDefaultPortResId, USHORT _nHelpTextResId, USHORT _nHeaderTextResId, USHORT _nDriverClassId)
+ OGeneralSpecialJDBCConnectionPageSetup::OGeneralSpecialJDBCConnectionPageSetup( Window* pParent,sal_uInt16 _nResId, const SfxItemSet& _rCoreAttrs ,sal_uInt16 _nPortId, sal_uInt16 _nDefaultPortResId, sal_uInt16 _nHelpTextResId, sal_uInt16 _nHeaderTextResId, sal_uInt16 _nDriverClassId)
:OGenericAdministrationPage(pParent, ModuleRes(_nResId), _rCoreAttrs)
,m_aFTHelpText (this, ModuleRes(FT_AUTOWIZARDHELPTEXT))
,m_aFTDatabasename (this, ModuleRes(FT_AUTODATABASENAME))
@@ -631,7 +631,7 @@ DBG_NAME(OMySQLIntroPageSetup)
{
}
- USHORT nMessage = bSuccess ? STR_JDBCDRIVER_SUCCESS : STR_JDBCDRIVER_NO_SUCCESS;
+ sal_uInt16 nMessage = bSuccess ? STR_JDBCDRIVER_SUCCESS : STR_JDBCDRIVER_NO_SUCCESS;
OSQLMessageBox aMsg( this, String( ModuleRes( nMessage ) ), String() );
aMsg.Execute();
return 0L;
@@ -726,7 +726,7 @@ DBG_NAME(OMySQLIntroPageSetup)
bool OJDBCConnectionPageSetup::checkTestConnection()
{
OSL_ENSURE(m_pAdminDialog,"No Admin dialog set! ->GPF");
- BOOL bEnableTestConnection = !m_aConnectionURL.IsVisible() || (m_aConnectionURL.GetTextNoPrefix().Len() != 0);
+ sal_Bool bEnableTestConnection = !m_aConnectionURL.IsVisible() || (m_aConnectionURL.GetTextNoPrefix().Len() != 0);
bEnableTestConnection = bEnableTestConnection && (m_aETDriverClass.GetText().Len() != 0);
return bEnableTestConnection;
// m_aTestConnection.Enable(bEnableTestConnection);
@@ -751,7 +751,7 @@ DBG_NAME(OMySQLIntroPageSetup)
{
}
- USHORT nMessage = bSuccess ? STR_JDBCDRIVER_SUCCESS : STR_JDBCDRIVER_NO_SUCCESS;
+ sal_uInt16 nMessage = bSuccess ? STR_JDBCDRIVER_SUCCESS : STR_JDBCDRIVER_NO_SUCCESS;
OSQLMessageBox aMsg( this, String( ModuleRes( nMessage ) ), String() );
aMsg.Execute();
return 0L;
diff --git a/dbaccess/source/ui/dlg/DBSetupConnectionPages.hxx b/dbaccess/source/ui/dlg/DBSetupConnectionPages.hxx
index 1ba67e19b9e2..441bd61fd61d 100644
--- a/dbaccess/source/ui/dlg/DBSetupConnectionPages.hxx
+++ b/dbaccess/source/ui/dlg/DBSetupConnectionPages.hxx
@@ -58,7 +58,7 @@ namespace dbaui
class OSpreadSheetConnectionPageSetup : public OConnectionTabPageSetup
{
public:
- virtual BOOL FillItemSet ( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet ( SfxItemSet& _rCoreAttrs );
static OGenericAdministrationPage* CreateSpreadSheetTabPage( Window* pParent, const SfxItemSet& _rAttrSet );
OSpreadSheetConnectionPageSetup(Window* pParent, const SfxItemSet& _rCoreAttrs);
@@ -79,7 +79,7 @@ namespace dbaui
class OTextConnectionPageSetup : public OConnectionTabPageSetup
{
public:
- virtual BOOL FillItemSet ( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet ( SfxItemSet& _rCoreAttrs );
static OGenericAdministrationPage* CreateTextTabPage( Window* pParent, const SfxItemSet& _rAttrSet );
OTextConnectionPageSetup( Window* pParent, const SfxItemSet& _rCoreAttrs );
OTextConnectionHelper* m_pTextConnectionHelper;
@@ -103,7 +103,7 @@ namespace dbaui
class OLDAPConnectionPageSetup : public OGenericAdministrationPage
{
public:
- virtual BOOL FillItemSet ( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet ( SfxItemSet& _rCoreAttrs );
static OGenericAdministrationPage* CreateLDAPTabPage( Window* pParent, const SfxItemSet& _rAttrSet );
OLDAPConnectionPageSetup( Window* pParent, const SfxItemSet& _rCoreAttrs );
virtual Link getControlModifiedLink() { return LINK(this, OLDAPConnectionPageSetup, OnEditModified); }
@@ -146,7 +146,7 @@ namespace dbaui
virtual void fillControls( ::std::vector< ISaveValueWrapper* >& _rControlList );
virtual void fillWindows( ::std::vector< ISaveValueWrapper* >& _rControlList );
- virtual BOOL FillItemSet( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet( SfxItemSet& _rCoreAttrs );
virtual void implInitControls(const SfxItemSet& _rSet, sal_Bool _bSaveValue);
virtual Link getControlModifiedLink();
@@ -162,18 +162,18 @@ namespace dbaui
{
public:
OGeneralSpecialJDBCConnectionPageSetup( Window* pParent
- , USHORT _nResId
+ , sal_uInt16 _nResId
, const SfxItemSet& _rCoreAttrs
- , USHORT _nPortId
- , USHORT _nDefaultPortResId
- , USHORT _nHelpTextResId
- , USHORT _nHeaderTextResId
- , USHORT _nDriverClassId );
+ , sal_uInt16 _nPortId
+ , sal_uInt16 _nDefaultPortResId
+ , sal_uInt16 _nHelpTextResId
+ , sal_uInt16 _nHeaderTextResId
+ , sal_uInt16 _nDriverClassId );
static OGenericAdministrationPage* CreateMySQLJDBCTabPage( Window* pParent, const SfxItemSet& _rAttrSet );
static OGenericAdministrationPage* CreateOracleJDBCTabPage( Window* pParent, const SfxItemSet& _rAttrSet );
protected:
- virtual BOOL FillItemSet( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet( SfxItemSet& _rCoreAttrs );
virtual void implInitControls(const SfxItemSet& _rSet, sal_Bool _bSaveValue);
virtual void fillControls(::std::vector< ISaveValueWrapper* >& _rControlList);
virtual void fillWindows(::std::vector< ISaveValueWrapper* >& _rControlList);
@@ -196,7 +196,7 @@ namespace dbaui
PushButton m_aPBTestJavaDriver;
String m_sDefaultJdbcDriverName;
- USHORT m_nPortId;
+ sal_uInt16 m_nPortId;
};
@@ -212,7 +212,7 @@ namespace dbaui
protected:
virtual bool checkTestConnection();
- virtual BOOL FillItemSet( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet( SfxItemSet& _rCoreAttrs );
virtual void implInitControls(const SfxItemSet& _rSet, sal_Bool _bSaveValue);
virtual void fillControls(::std::vector< ISaveValueWrapper* >& _rControlList);
virtual void fillWindows(::std::vector< ISaveValueWrapper* >& _rControlList);
@@ -252,7 +252,7 @@ namespace dbaui
protected:
- virtual BOOL FillItemSet(SfxItemSet& _rSet);
+ virtual sal_Bool FillItemSet(SfxItemSet& _rSet);
virtual void implInitControls(const SfxItemSet& _rSet, sal_Bool _bSaveValue);
virtual void fillControls(::std::vector< ISaveValueWrapper* >& _rControlList);
virtual void fillWindows(::std::vector< ISaveValueWrapper* >& _rControlList);
@@ -279,7 +279,7 @@ namespace dbaui
class OAuthentificationPageSetup : public OGenericAdministrationPage
{
public:
- virtual BOOL FillItemSet ( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet ( SfxItemSet& _rCoreAttrs );
static OGenericAdministrationPage* CreateAuthentificationTabPage( Window* pParent, const SfxItemSet& _rAttrSet );
OAuthentificationPageSetup(Window* pParent, const SfxItemSet& _rCoreAttrs);
@@ -306,7 +306,7 @@ namespace dbaui
class OFinalDBPageSetup : public OGenericAdministrationPage
{
public:
- virtual BOOL FillItemSet ( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet ( SfxItemSet& _rCoreAttrs );
static OGenericAdministrationPage* CreateFinalDBTabPageSetup( Window* pParent, const SfxItemSet& _rAttrSet);
FixedText m_aFTFinalHeader;
diff --git a/dbaccess/source/ui/dlg/DbAdminImpl.cxx b/dbaccess/source/ui/dlg/DbAdminImpl.cxx
index 797cb73eb021..6863f1601adc 100755..100644
--- a/dbaccess/source/ui/dlg/DbAdminImpl.cxx
+++ b/dbaccess/source/ui/dlg/DbAdminImpl.cxx
@@ -104,7 +104,7 @@ using namespace com::sun::star::frame;
//-------------------------------------------------------------------------
namespace
{
- sal_Bool implCheckItemType( SfxItemSet& _rSet, const USHORT _nId, const TypeId _nExpectedItemType )
+ sal_Bool implCheckItemType( SfxItemSet& _rSet, const sal_uInt16 _nId, const TypeId _nExpectedItemType )
{
sal_Bool bCorrectType = sal_False;
@@ -723,7 +723,7 @@ void ODbDataSourceAdministrationHelper::translateProperties(const SfxItemSet& _r
++aDirect
)
{
- const SfxPoolItem* pCurrentItem = _rSource.GetItem((USHORT)aDirect->first);
+ const SfxPoolItem* pCurrentItem = _rSource.GetItem((sal_uInt16)aDirect->first);
if (pCurrentItem)
{
sal_Int16 nAttributes = PropertyAttribute::READONLY;
@@ -782,7 +782,7 @@ void ODbDataSourceAdministrationHelper::fillDatasourceInfo(const SfxItemSet& _rS
::std::vector< sal_Int32>::iterator aDetailsEnd = aDetailIds.end();
for (::std::vector< sal_Int32>::iterator aIter = aDetailIds.begin();aIter != aDetailsEnd ; ++aIter)
{
- const SfxPoolItem* pCurrent = _rSource.GetItem((USHORT)*aIter);
+ const SfxPoolItem* pCurrent = _rSource.GetItem((sal_uInt16)*aIter);
aTranslation = m_aIndirectPropTranslator.find(*aIter);
if ( pCurrent && (m_aIndirectPropTranslator.end() != aTranslation) )
{
@@ -1115,7 +1115,7 @@ void ODbDataSourceAdministrationHelper::convertUrl(SfxItemSet& _rDest)
::dbaccess::ODsnTypeCollection* pCollection = pTypeCollection->getCollection();
DBG_ASSERT(pCollection, "ODbAdminDialog::getDatasourceType: invalid type collection!");
- USHORT nPortNumberId = 0;
+ sal_uInt16 nPortNumberId = 0;
sal_Int32 nPortNumber = -1;
String sNewHostName;
//String sUrl = pCollection->cutPrefix(pUrlItem->GetValue());
diff --git a/dbaccess/source/ui/dlg/DriverSettings.cxx b/dbaccess/source/ui/dlg/DriverSettings.cxx
index cecdc49aff8e..b94db6114e8e 100644
--- a/dbaccess/source/ui/dlg/DriverSettings.cxx
+++ b/dbaccess/source/ui/dlg/DriverSettings.cxx
@@ -77,7 +77,7 @@ void ODriversSettings::getSupportedIndirectSettings( const ::rtl::OUString& _sUR
}
}
#endif
- typedef ::std::pair<USHORT, ::rtl::OUString> TProperties;
+ typedef ::std::pair<sal_uInt16, ::rtl::OUString> TProperties;
TProperties aProps[] = { TProperties(DSID_SHOWDELETEDROWS,::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ShowDeleted")))
,TProperties(DSID_CHARSET,::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("CharSet")))
,TProperties(DSID_FIELDDELIMITER,::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("FieldDelimiter")))
diff --git a/dbaccess/source/ui/dlg/UserAdminDlg.cxx b/dbaccess/source/ui/dlg/UserAdminDlg.cxx
index 37f28bcaa828..17c180b04eec 100644
--- a/dbaccess/source/ui/dlg/UserAdminDlg.cxx
+++ b/dbaccess/source/ui/dlg/UserAdminDlg.cxx
@@ -133,7 +133,7 @@ DBG_NAME(OUserAdminDlg)
return nRet;
}
//-------------------------------------------------------------------------
- void OUserAdminDlg::PageCreated(USHORT _nId, SfxTabPage& _rPage)
+ void OUserAdminDlg::PageCreated(sal_uInt16 _nId, SfxTabPage& _rPage)
{
// register ourself as modified listener
static_cast<OGenericAdministrationPage&>(_rPage).SetServiceFactory(m_pImpl->getORB());
diff --git a/dbaccess/source/ui/dlg/admincontrols.cxx b/dbaccess/source/ui/dlg/admincontrols.cxx
index 463358e179d5..71282c879bf6 100755
--- a/dbaccess/source/ui/dlg/admincontrols.cxx
+++ b/dbaccess/source/ui/dlg/admincontrols.cxx
@@ -78,7 +78,7 @@ namespace dbaui
private:
const String m_sDisabledText;
String m_sUserText;
- BOOL m_bLastKnownEnabledState;
+ sal_Bool m_bLastKnownEnabledState;
};
//--------------------------------------------------------------------
@@ -150,7 +150,7 @@ namespace dbaui
//====================================================================
//--------------------------------------------------------------------
MySQLNativeSettings::MySQLNativeSettings( Window& _rParent, const Link& _rControlModificationLink )
- :Control( &_rParent, ModuleRes( RID_MYSQL_NATIVE_SETTINGS ).SetAutoRelease( FALSE ) )
+ :Control( &_rParent, ModuleRes( RID_MYSQL_NATIVE_SETTINGS ).SetAutoRelease( sal_False ) )
,m_aDatabaseNameLabel ( this, ModuleRes( FT_MYSQL_DATABASE_NAME ) )
,m_aDatabaseName ( this, ModuleRes( ED_MYSQL_DATABASE_NAME ) )
,m_aHostPortRadio ( this, ModuleRes( RB_MYSQL_HOST_PORT ) )
@@ -218,7 +218,7 @@ namespace dbaui
}
//--------------------------------------------------------------------
- BOOL MySQLNativeSettings::FillItemSet( SfxItemSet& _rSet )
+ sal_Bool MySQLNativeSettings::FillItemSet( SfxItemSet& _rSet )
{
sal_Bool bChangedSomething = sal_False;
diff --git a/dbaccess/source/ui/dlg/admincontrols.hxx b/dbaccess/source/ui/dlg/admincontrols.hxx
index e4526dffb8d2..70ee08d5ca28 100755
--- a/dbaccess/source/ui/dlg/admincontrols.hxx
+++ b/dbaccess/source/ui/dlg/admincontrols.hxx
@@ -69,7 +69,7 @@ namespace dbaui
void fillControls( ::std::vector< ISaveValueWrapper* >& _rControlList );
void fillWindows( ::std::vector< ISaveValueWrapper* >& _rControlList );
- BOOL FillItemSet( SfxItemSet& _rCoreAttrs );
+ sal_Bool FillItemSet( SfxItemSet& _rCoreAttrs );
void implInitControls( const SfxItemSet& _rSet );
bool canAdvance() const;
diff --git a/dbaccess/source/ui/dlg/adminpages.cxx b/dbaccess/source/ui/dlg/adminpages.cxx
index d19052525a76..a023ed240eaa 100644
--- a/dbaccess/source/ui/dlg/adminpages.cxx
+++ b/dbaccess/source/ui/dlg/adminpages.cxx
@@ -214,7 +214,7 @@ namespace dbaui
return true;
}
// -----------------------------------------------------------------------
- void OGenericAdministrationPage::fillBool( SfxItemSet& _rSet, CheckBox* _pCheckBox, USHORT _nID, sal_Bool& _bChangedSomething, bool _bRevertValue )
+ void OGenericAdministrationPage::fillBool( SfxItemSet& _rSet, CheckBox* _pCheckBox, sal_uInt16 _nID, sal_Bool& _bChangedSomething, bool _bRevertValue )
{
if ( (_pCheckBox != NULL ) && ( _pCheckBox->GetState() != _pCheckBox->GetSavedValue() ) )
{
@@ -236,16 +236,16 @@ namespace dbaui
}
}
// -----------------------------------------------------------------------
- void OGenericAdministrationPage::fillInt32(SfxItemSet& _rSet,NumericField* _pEdit,USHORT _nID,sal_Bool& _bChangedSomething)
+ void OGenericAdministrationPage::fillInt32(SfxItemSet& _rSet,NumericField* _pEdit,sal_uInt16 _nID,sal_Bool& _bChangedSomething)
{
if( (_pEdit != NULL) && (_pEdit->GetValue() != _pEdit->GetSavedValue().ToInt32()) )
{
- _rSet.Put(SfxInt32Item(_nID, static_cast<INT32>(_pEdit->GetValue())));
+ _rSet.Put(SfxInt32Item(_nID, static_cast<sal_Int32>(_pEdit->GetValue())));
_bChangedSomething = sal_True;
}
}
// -----------------------------------------------------------------------
- void OGenericAdministrationPage::fillString(SfxItemSet& _rSet,Edit* _pEdit,USHORT _nID,sal_Bool& _bChangedSomething)
+ void OGenericAdministrationPage::fillString(SfxItemSet& _rSet,Edit* _pEdit,sal_uInt16 _nID,sal_Bool& _bChangedSomething)
{
if( (_pEdit != NULL) && (_pEdit->GetText() != _pEdit->GetSavedValue()) )
{
@@ -304,7 +304,7 @@ namespace dbaui
return 0L;
}
- void OGenericAdministrationPage::SetHeaderText( USHORT _nFTResId, USHORT _StringResId)
+ void OGenericAdministrationPage::SetHeaderText( sal_uInt16 _nFTResId, sal_uInt16 _StringResId)
{
delete(m_pFT_HeaderText);
m_pFT_HeaderText = new FixedText(this, ModuleRes(_nFTResId));
diff --git a/dbaccess/source/ui/dlg/adminpages.hxx b/dbaccess/source/ui/dlg/adminpages.hxx
index be6b923c2997..c3773b8109cd 100644
--- a/dbaccess/source/ui/dlg/adminpages.hxx
+++ b/dbaccess/source/ui/dlg/adminpages.hxx
@@ -227,7 +227,7 @@ namespace dbaui
@param _bRevertValue
set to <TRUE/> if the display value should be reverted before putting it into the set
*/
- static void fillBool( SfxItemSet& _rSet, CheckBox* _pCheckBox, USHORT _nID, sal_Bool& _bChangedSomething, bool _bRevertValue = false);
+ static void fillBool( SfxItemSet& _rSet, CheckBox* _pCheckBox, sal_uInt16 _nID, sal_Bool& _bChangedSomething, bool _bRevertValue = false);
/** fills the int value into the item set when the value changed.
@param _rSet
@@ -239,7 +239,7 @@ namespace dbaui
@param _bChangedSomething
<TRUE/> if something changed otherwise <FALSE/>
*/
- static void fillInt32(SfxItemSet& _rSet,NumericField* _pEdit,USHORT _nID,sal_Bool& _bChangedSomething);
+ static void fillInt32(SfxItemSet& _rSet,NumericField* _pEdit,sal_uInt16 _nID,sal_Bool& _bChangedSomething);
/** fills the String value into the item set when the value changed.
@param _rSet
@@ -251,12 +251,12 @@ namespace dbaui
@param _bChangedSomething
<TRUE/> if something changed otherwise <FALSE/>
*/
- static void fillString(SfxItemSet& _rSet,Edit* _pEdit,USHORT _nID,sal_Bool& _bChangedSomething);
+ static void fillString(SfxItemSet& _rSet,Edit* _pEdit,sal_uInt16 _nID,sal_Bool& _bChangedSomething);
protected:
// used to set the right Pane header of a wizard to bold
void SetControlFontWeight(Window* _pWindow, FontWeight _eWeight = WEIGHT_BOLD);
- void SetHeaderText( USHORT _nFTResId, USHORT _StringResId);
+ void SetHeaderText( sal_uInt16 _nFTResId, sal_uInt16 _StringResId);
/** This link be used for controls where the tabpage does not need to take any special action when the control
is modified. The implementation just calls callModifiedHdl.
diff --git a/dbaccess/source/ui/dlg/adodatalinks.cxx b/dbaccess/source/ui/dlg/adodatalinks.cxx
index 4b7005976778..760bd7b3f4ab 100644
--- a/dbaccess/source/ui/dlg/adodatalinks.cxx
+++ b/dbaccess/source/ui/dlg/adodatalinks.cxx
@@ -175,7 +175,7 @@ BSTR PromptEdit(long hWnd,BSTR connstr)
// Prompt for connection information.
hr = dlPrompt->PromptEdit((IDispatch **)&piTmpConnection,&pbSuccess);
- if( SUCCEEDED( hr ) && FALSE == pbSuccess ) //if user press cancel then FALSE == pbSuccess
+ if( SUCCEEDED( hr ) && sal_False == pbSuccess ) //if user press cancel then sal_False == pbSuccess
{
piTmpConnection->Release( );
dlPrompt->Release( );
diff --git a/dbaccess/source/ui/dlg/adodatalinks.hxx b/dbaccess/source/ui/dlg/adodatalinks.hxx
index 7daf5cda61e0..2084bb850402 100644
--- a/dbaccess/source/ui/dlg/adodatalinks.hxx
+++ b/dbaccess/source/ui/dlg/adodatalinks.hxx
@@ -36,4 +36,4 @@
#endif
::rtl::OUString getAdoDatalink(long hWnd,::rtl::OUString& oldLink);
-#endif \ No newline at end of file
+#endif
diff --git a/dbaccess/source/ui/dlg/adtabdlg.cxx b/dbaccess/source/ui/dlg/adtabdlg.cxx
index 4ef32efcc7ac..55f4a25fc6e1 100644
--- a/dbaccess/source/ui/dlg/adtabdlg.cxx
+++ b/dbaccess/source/ui/dlg/adtabdlg.cxx
@@ -376,7 +376,7 @@ OAddTableDlg::OAddTableDlg( Window* pParent, IAddTableDialogContext& _rContext )
m_aQueryList.SetSelectHdl( LINK( this, OAddTableDlg, TableListSelectHdl ) );
//////////////////////////////////////////////////////////////////////
- m_aTableList.EnableInplaceEditing( FALSE );
+ m_aTableList.EnableInplaceEditing( sal_False );
m_aTableList.SetStyle(m_aTableList.GetStyle() | WB_BORDER | WB_HASLINES |WB_HASBUTTONS | WB_HASBUTTONSATROOT | WB_HASLINESATROOT | WB_SORT | WB_HSCROLL );
m_aTableList.EnableCheckButton( NULL ); // do not show any buttons
m_aTableList.SetSelectionMode( SINGLE_SELECTION );
@@ -384,7 +384,7 @@ OAddTableDlg::OAddTableDlg( Window* pParent, IAddTableDialogContext& _rContext )
m_aTableList.suppressEmptyFolders();
//////////////////////////////////////////////////////////////////////
- m_aQueryList.EnableInplaceEditing( FALSE );
+ m_aQueryList.EnableInplaceEditing( sal_False );
m_aQueryList.SetSelectionMode( SINGLE_SELECTION );
//////////////////////////////////////////////////////////////////////
@@ -421,15 +421,15 @@ void OAddTableDlg::impl_switchTo( ObjectList _eList )
switch ( _eList )
{
case Tables:
- m_aTableList.Show( TRUE ); m_aCaseTables.Check( TRUE );
- m_aQueryList.Show( FALSE ); m_aCaseQueries.Check( FALSE );
+ m_aTableList.Show( sal_True ); m_aCaseTables.Check( sal_True );
+ m_aQueryList.Show( sal_False ); m_aCaseQueries.Check( sal_False );
m_pCurrentList.reset( new TableListFacade( m_aTableList, m_rContext.getConnection() ) );
m_aTableList.GrabFocus();
break;
case Queries:
- m_aTableList.Show( FALSE ); m_aCaseTables.Check( FALSE );
- m_aQueryList.Show( TRUE ); m_aCaseQueries.Check( TRUE );
+ m_aTableList.Show( sal_False ); m_aCaseTables.Check( sal_False );
+ m_aQueryList.Show( sal_True ); m_aCaseQueries.Check( sal_True );
m_pCurrentList.reset( new QueryListFacade( m_aQueryList, m_rContext.getConnection() ) );
m_aQueryList.GrabFocus();
break;
@@ -503,7 +503,7 @@ IMPL_LINK( OAddTableDlg, OnTypeSelected, void*, /*EMPTY_ARG*/ )
}
//------------------------------------------------------------------------------
-BOOL OAddTableDlg::Close()
+sal_Bool OAddTableDlg::Close()
{
m_rContext.onWindowClosing( this );
return ModelessDialog::Close();
diff --git a/dbaccess/source/ui/dlg/advancedsettings.hxx b/dbaccess/source/ui/dlg/advancedsettings.hxx
index 07620496b11f..8777a4654039 100644
--- a/dbaccess/source/ui/dlg/advancedsettings.hxx
+++ b/dbaccess/source/ui/dlg/advancedsettings.hxx
@@ -89,7 +89,7 @@ namespace dbaui
bool m_bHasMaxRowScan;
public:
- virtual BOOL FillItemSet ( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet ( SfxItemSet& _rCoreAttrs );
SpecialSettingsPage(Window* pParent, const SfxItemSet& _rCoreAttrs, const DataSourceMetaData& _rDSMeta );
@@ -127,7 +127,7 @@ namespace dbaui
m_aControlDependencies;
public:
- virtual BOOL FillItemSet (SfxItemSet& _rCoreAttrs);
+ virtual sal_Bool FillItemSet (SfxItemSet& _rCoreAttrs);
GeneratedValuesPage( Window* pParent, const SfxItemSet& _rCoreAttrs );
protected:
diff --git a/dbaccess/source/ui/dlg/dbadmin.cxx b/dbaccess/source/ui/dlg/dbadmin.cxx
index 1c1b945854ed..b1d87372a05b 100644
--- a/dbaccess/source/ui/dlg/dbadmin.cxx
+++ b/dbaccess/source/ui/dlg/dbadmin.cxx
@@ -108,7 +108,7 @@ short ODbAdminDialog::Ok()
}
//-------------------------------------------------------------------------
-void ODbAdminDialog::PageCreated(USHORT _nId, SfxTabPage& _rPage)
+void ODbAdminDialog::PageCreated(sal_uInt16 _nId, SfxTabPage& _rPage)
{
// register ourself as modified listener
static_cast<OGenericAdministrationPage&>(_rPage).SetServiceFactory(m_pImpl->getORB());
@@ -123,7 +123,7 @@ void ODbAdminDialog::PageCreated(USHORT _nId, SfxTabPage& _rPage)
}
// -----------------------------------------------------------------------------
-void ODbAdminDialog::addDetailPage(USHORT _nPageId, USHORT _nTextId, CreateTabPage _pCreateFunc)
+void ODbAdminDialog::addDetailPage(sal_uInt16 _nPageId, sal_uInt16 _nTextId, CreateTabPage _pCreateFunc)
{
// open our own resource block, as the page titles are strings local to this block
LocalResourceAccess aDummy(DLG_DATABASE_ADMINISTRATION, RSC_TABDIALOG);
diff --git a/dbaccess/source/ui/dlg/dbfindex.hxx b/dbaccess/source/ui/dlg/dbfindex.hxx
index 5189bb34810d..28e80aac5963 100644
--- a/dbaccess/source/ui/dlg/dbfindex.hxx
+++ b/dbaccess/source/ui/dlg/dbfindex.hxx
@@ -137,7 +137,7 @@ protected:
String m_aDSN;
TableInfoList m_aTableInfoList;
TableIndexList m_aFreeIndexList;
- BOOL m_bCaseSensitiv;
+ sal_Bool m_bCaseSensitiv;
void Init();
void SetCtrls();
diff --git a/dbaccess/source/ui/dlg/dbwiz.cxx b/dbaccess/source/ui/dlg/dbwiz.cxx
index 7fcf2ae8429d..3ebd34955a52 100644
--- a/dbaccess/source/ui/dlg/dbwiz.cxx
+++ b/dbaccess/source/ui/dlg/dbwiz.cxx
@@ -295,7 +295,7 @@ void ODbTypeWizDialog::clearPassword()
// -----------------------------------------------------------------------------
TabPage* ODbTypeWizDialog::createPage(WizardState _nState)
{
- USHORT nStringId = STR_PAGETITLE_ADVANCED;
+ sal_uInt16 nStringId = STR_PAGETITLE_ADVANCED;
TabPage* pPage = NULL;
switch(_nState)
{
diff --git a/dbaccess/source/ui/dlg/detailpages.cxx b/dbaccess/source/ui/dlg/detailpages.cxx
index d90dbd8bc296..9ddd6282bfe4 100644
--- a/dbaccess/source/ui/dlg/detailpages.cxx
+++ b/dbaccess/source/ui/dlg/detailpages.cxx
@@ -101,7 +101,7 @@ namespace dbaui
//========================================================================
DBG_NAME(OCommonBehaviourTabPage)
//------------------------------------------------------------------------
- OCommonBehaviourTabPage::OCommonBehaviourTabPage(Window* pParent, USHORT nResId, const SfxItemSet& _rCoreAttrs,
+ OCommonBehaviourTabPage::OCommonBehaviourTabPage(Window* pParent, sal_uInt16 nResId, const SfxItemSet& _rCoreAttrs,
sal_uInt32 nControlFlags,bool _bFreeResource)
:OGenericAdministrationPage(pParent, ModuleRes(nResId), _rCoreAttrs)
@@ -525,7 +525,7 @@ namespace dbaui
//========================================================================
//= OMySQLJDBCDetailsPage
//========================================================================
- OGeneralSpecialJDBCDetailsPage::OGeneralSpecialJDBCDetailsPage( Window* pParent,USHORT _nResId, const SfxItemSet& _rCoreAttrs ,USHORT _nPortId)
+ OGeneralSpecialJDBCDetailsPage::OGeneralSpecialJDBCDetailsPage( Window* pParent,sal_uInt16 _nResId, const SfxItemSet& _rCoreAttrs ,sal_uInt16 _nPortId)
:OCommonBehaviourTabPage(pParent, _nResId, _rCoreAttrs, CBTP_USE_CHARSET ,false)
,m_aFL_1 (this, ModuleRes( FL_SEPARATOR1) )
,m_aFTHostname (this, ModuleRes(FT_HOSTNAME))
@@ -556,9 +556,9 @@ namespace dbaui
else
{
m_bUseClass = false;
- m_aFTDriverClass.Show(FALSE);
- m_aEDDriverClass.Show(FALSE);
- m_aTestJavaDriver.Show(FALSE);
+ m_aFTDriverClass.Show(sal_False);
+ m_aEDDriverClass.Show(sal_False);
+ m_aTestJavaDriver.Show(sal_False);
}
m_aFTSocket.Show(PAGE_MYSQL_JDBC == _nResId && !m_bUseClass);
@@ -673,7 +673,7 @@ namespace dbaui
{
}
- USHORT nMessage = bSuccess ? STR_JDBCDRIVER_SUCCESS : STR_JDBCDRIVER_NO_SUCCESS;
+ sal_uInt16 nMessage = bSuccess ? STR_JDBCDRIVER_SUCCESS : STR_JDBCDRIVER_NO_SUCCESS;
OSQLMessageBox aMsg( this, String( ModuleRes( nMessage ) ), String() );
aMsg.Execute();
return 0L;
@@ -925,7 +925,7 @@ namespace dbaui
IMPL_LINK( OAdabasDetailsPage, AttributesChangedHdl, void *, EMPTYARG )
{
m_CB_SHUTDB.Enable(m_ET_CTRLUSERNAME.GetText().Len() && m_ET_CTRLPASSWORD.GetText().Len());
- bAttrsChanged = TRUE;
+ bAttrsChanged = sal_True;
callModifiedHdl();
return 0;
}
diff --git a/dbaccess/source/ui/dlg/detailpages.hxx b/dbaccess/source/ui/dlg/detailpages.hxx
index e93fa9b201c4..2e7b90cd00ab 100644
--- a/dbaccess/source/ui/dlg/detailpages.hxx
+++ b/dbaccess/source/ui/dlg/detailpages.hxx
@@ -98,9 +98,9 @@ namespace dbaui
sal_uInt32 m_nControlFlags;
public:
- virtual BOOL FillItemSet (SfxItemSet& _rCoreAttrs);
+ virtual sal_Bool FillItemSet (SfxItemSet& _rCoreAttrs);
- OCommonBehaviourTabPage(Window* pParent, USHORT nResId, const SfxItemSet& _rCoreAttrs, sal_uInt32 nControlFlags,bool _bFreeResource = true);
+ OCommonBehaviourTabPage(Window* pParent, sal_uInt16 nResId, const SfxItemSet& _rCoreAttrs, sal_uInt32 nControlFlags,bool _bFreeResource = true);
protected:
// nControlFlags ist eine Kombination der CBTP_xxx-Konstanten
@@ -122,7 +122,7 @@ namespace dbaui
class ODbaseDetailsPage : public OCommonBehaviourTabPage
{
public:
- virtual BOOL FillItemSet ( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet ( SfxItemSet& _rCoreAttrs );
ODbaseDetailsPage(Window* pParent, const SfxItemSet& _rCoreAttrs);
private:
@@ -165,7 +165,7 @@ namespace dbaui
class OOdbcDetailsPage : public OCommonBehaviourTabPage
{
public:
- virtual BOOL FillItemSet ( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet ( SfxItemSet& _rCoreAttrs );
OOdbcDetailsPage( Window* pParent, const SfxItemSet& _rCoreAttrs );
protected:
@@ -184,7 +184,7 @@ namespace dbaui
class OUserDriverDetailsPage : public OCommonBehaviourTabPage
{
public:
- virtual BOOL FillItemSet ( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet ( SfxItemSet& _rCoreAttrs );
OUserDriverDetailsPage( Window* pParent, const SfxItemSet& _rCoreAttrs );
protected:
@@ -215,15 +215,15 @@ namespace dbaui
{
public:
OGeneralSpecialJDBCDetailsPage( Window* pParent
- , USHORT _nResId
+ , sal_uInt16 _nResId
, const SfxItemSet& _rCoreAttrs
- , USHORT _nPortId
+ , sal_uInt16 _nPortId
);
protected:
- virtual BOOL FillItemSet( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet( SfxItemSet& _rCoreAttrs );
virtual void implInitControls(const SfxItemSet& _rSet, sal_Bool _bSaveValue);
virtual void fillControls(::std::vector< ISaveValueWrapper* >& _rControlList);
virtual void fillWindows(::std::vector< ISaveValueWrapper* >& _rControlList);
@@ -244,7 +244,7 @@ namespace dbaui
PushButton m_aTestJavaDriver;
String m_sDefaultJdbcDriverName;
- USHORT m_nPortId;
+ sal_uInt16 m_nPortId;
bool m_bUseClass;
};
@@ -267,7 +267,7 @@ namespace dbaui
CheckBox m_aPasswordRequired;
protected:
- virtual BOOL FillItemSet( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet( SfxItemSet& _rCoreAttrs );
virtual void implInitControls(const SfxItemSet& _rSet, sal_Bool _bSaveValue);
virtual void fillControls(::std::vector< ISaveValueWrapper* >& _rControlList);
virtual void fillWindows(::std::vector< ISaveValueWrapper* >& _rControlList);
@@ -279,7 +279,7 @@ namespace dbaui
class OAdabasDetailsPage : public OCommonBehaviourTabPage
{
public:
- virtual BOOL FillItemSet (SfxItemSet& _rCoreAttrs);
+ virtual sal_Bool FillItemSet (SfxItemSet& _rCoreAttrs);
OAdabasDetailsPage( Window* pParent, const SfxItemSet& _rCoreAttrs );
protected:
@@ -306,7 +306,7 @@ namespace dbaui
CheckBox m_CB_SHUTDB;
PushButton m_PB_STAT;
String m_sUser;
- BOOL bAttrsChanged;
+ sal_Bool bAttrsChanged;
DECL_LINK( AttributesChangedHdl, void * );
DECL_LINK( UserSettingsHdl, void * );
@@ -320,7 +320,7 @@ namespace dbaui
class OLDAPDetailsPage : public OCommonBehaviourTabPage
{
public:
- virtual BOOL FillItemSet ( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet ( SfxItemSet& _rCoreAttrs );
OLDAPDetailsPage( Window* pParent, const SfxItemSet& _rCoreAttrs );
protected:
@@ -360,7 +360,7 @@ namespace dbaui
class OTextDetailsPage : public OCommonBehaviourTabPage
{
public:
- virtual BOOL FillItemSet ( SfxItemSet& _rCoreAttrs );
+ virtual sal_Bool FillItemSet ( SfxItemSet& _rCoreAttrs );
OTextDetailsPage( Window* pParent, const SfxItemSet& _rCoreAttrs );
OTextConnectionHelper* m_pTextConnectionHelper;
diff --git a/dbaccess/source/ui/dlg/directsql.cxx b/dbaccess/source/ui/dlg/directsql.cxx
index 9465cfa58fed..87086e556226 100644
--- a/dbaccess/source/ui/dlg/directsql.cxx
+++ b/dbaccess/source/ui/dlg/directsql.cxx
@@ -188,7 +188,7 @@ DBG_NAME(DirectSQLDialog)
{
m_aStatementHistory.pop_front();
m_aNormalizedHistory.pop_front();
- m_pSQLHistory->RemoveEntry((USHORT)0);
+ m_pSQLHistory->RemoveEntry((sal_uInt16)0);
}
}
@@ -316,7 +316,7 @@ DBG_NAME(DirectSQLDialog)
if (_bUpdateListBox)
{
// selecte the normalized statement in the list box
- m_pSQLHistory->SelectEntryPos((USHORT)_nHistoryPos);
+ m_pSQLHistory->SelectEntryPos((sal_uInt16)_nHistoryPos);
OSL_ENSURE(m_pSQLHistory->GetSelectEntry() == m_aNormalizedHistory[_nHistoryPos],
"DirectSQLDialog::switchToHistory: inconsistent listbox entries!");
}
diff --git a/dbaccess/source/ui/dlg/dlgattr.cxx b/dbaccess/source/ui/dlg/dlgattr.cxx
index 0608997ef0c1..5e8f5c0e2ca1 100644
--- a/dbaccess/source/ui/dlg/dlgattr.cxx
+++ b/dbaccess/source/ui/dlg/dlgattr.cxx
@@ -81,7 +81,7 @@ using namespace dbaui;
DBG_NAME(SbaSbAttrDlg)
//==================================================================
-SbaSbAttrDlg::SbaSbAttrDlg(Window* pParent, const SfxItemSet* pCellAttrs, SvNumberFormatter* pFormatter, USHORT nFlags, BOOL bRow)
+SbaSbAttrDlg::SbaSbAttrDlg(Window* pParent, const SfxItemSet* pCellAttrs, SvNumberFormatter* pFormatter, sal_uInt16 nFlags, sal_Bool bRow)
: SfxTabDialog(pParent, ModuleRes( DLG_ATTR ), pCellAttrs )
,aTitle(ModuleRes(ST_ROW))
{
@@ -121,7 +121,7 @@ void SbaSbAttrDlg::PageCreated( sal_uInt16 nPageId, SfxTabPage& rTabPage )
{
//CHINA001 ((SvxNumberFormatTabPage&)rTabPage).
//CHINA001 SetNumberFormatList( *pNumberInfoItem );
- aSet.Put (SvxNumberInfoItem( pNumberInfoItem->GetNumberFormatter(), (const USHORT)SID_ATTR_NUMBERFORMAT_INFO));
+ aSet.Put (SvxNumberInfoItem( pNumberInfoItem->GetNumberFormatter(), (const sal_uInt16)SID_ATTR_NUMBERFORMAT_INFO));
rTabPage.PageCreated(aSet);
}
break;
diff --git a/dbaccess/source/ui/dlg/dlgsave.cxx b/dbaccess/source/ui/dlg/dlgsave.cxx
index 7a287829057d..cd864ff5c29c 100644
--- a/dbaccess/source/ui/dlg/dlgsave.cxx
+++ b/dbaccess/source/ui/dlg/dlgsave.cxx
@@ -224,7 +224,7 @@ namespace
_rList.InsertEntry( sValue );
}
- USHORT nPos = _rList.GetEntryPos( String( _rCurrent ) );
+ sal_uInt16 nPos = _rList.GetEntryPos( String( _rCurrent ) );
if ( nPos != COMBOBOX_ENTRY_NOTFOUND )
_rList.SelectEntryPos( nPos );
else
@@ -308,7 +308,7 @@ OSaveAsDlg::OSaveAsDlg( Window * pParent,
sTable,
::dbtools::eInDataManipulation);
- USHORT nPos = m_pImpl->m_aCatalog.GetEntryPos(String(sCatalog));
+ sal_uInt16 nPos = m_pImpl->m_aCatalog.GetEntryPos(String(sCatalog));
if ( nPos != COMBOBOX_ENTRY_NOTFOUND )
m_pImpl->m_aCatalog.SelectEntryPos(nPos);
@@ -328,7 +328,7 @@ OSaveAsDlg::OSaveAsDlg( Window * pParent,
m_pImpl->m_aPB_CANCEL.SetPosPixel(Point(m_pImpl->m_aPB_CANCEL.GetPosPixel().X(),aPos.Y()));
m_pImpl->m_aPB_HELP.SetPosPixel(Point(m_pImpl->m_aPB_HELP.GetPosPixel().X(),aPos.Y()));
- USHORT nLength = m_pImpl->m_xMetaData.is() ? static_cast<USHORT>(m_pImpl->m_xMetaData->getMaxTableNameLength()) : 0;
+ sal_uInt16 nLength = m_pImpl->m_xMetaData.is() ? static_cast<sal_uInt16>(m_pImpl->m_xMetaData->getMaxTableNameLength()) : 0;
nLength = nLength ? nLength : EDIT_NOLIMIT;
m_pImpl->m_aTitle.SetMaxTextLen(nLength);
diff --git a/dbaccess/source/ui/dlg/dlgsize.src b/dbaccess/source/ui/dlg/dlgsize.src
index 128241d211e0..ea2a97d5910c 100644
--- a/dbaccess/source/ui/dlg/dlgsize.src
+++ b/dbaccess/source/ui/dlg/dlgsize.src
@@ -24,17 +24,6 @@
* for a copy of the LGPLv3 License.
*
************************************************************************/
- //---------------------------------------------------------------------------
- //
- // (c) Copyright 1996 - 2000 by Star Division GmbH, Hamburg, Germany
- //
- // Ersterstellung:
- // JN
- //
- // Letzte Aenderung:
- // $Author: rt $ $Date: 2008-04-10 14:52:17 $ $Revision: 1.32 $
- //
- //---------------------------------------------------------------------------
#ifndef DBAUI_DLGSIZE_HRC
#include "dlgsize.hrc"
diff --git a/dbaccess/source/ui/dlg/dsselect.cxx b/dbaccess/source/ui/dlg/dsselect.cxx
index b710cf990047..b2eec08a2db5 100644
--- a/dbaccess/source/ui/dlg/dsselect.cxx
+++ b/dbaccess/source/ui/dlg/dsselect.cxx
@@ -222,7 +222,7 @@ IMPL_LINK( ODatasourceSelectDialog, CreateDBClickHdl, PushButton*, /*pButton*/ )
if ( xPropInfo->hasPropertyByName(PROPERTY_PASSWORD) )
{
m_pOutputSet->Put(SfxStringItem(DSID_PASSWORD, ::comphelper::getString(xProp->getPropertyValue(PROPERTY_PASSWORD))));
- m_pOutputSet->Put(SfxBoolItem(DSID_PASSWORDREQUIRED, TRUE));
+ m_pOutputSet->Put(SfxBoolItem(DSID_PASSWORDREQUIRED, sal_True));
}
if ( xPropInfo->hasPropertyByName(PROPERTY_CACHESIZE) )
m_pOutputSet->Put(SfxInt32Item(DSID_CONN_CACHESIZE, ::comphelper::getINT32(xProp->getPropertyValue(PROPERTY_CACHESIZE))));
@@ -237,11 +237,11 @@ IMPL_LINK( ODatasourceSelectDialog, CreateDBClickHdl, PushButton*, /*pButton*/ )
}
// -----------------------------------------------------------------------
-BOOL ODatasourceSelectDialog::Close()
+sal_Bool ODatasourceSelectDialog::Close()
{
#ifdef HAVE_ODBC_ADMINISTRATION
if ( m_pODBCManagement.get() && m_pODBCManagement->isRunning() )
- return FALSE;
+ return sal_False;
#endif
return ModalDialog::Close();
diff --git a/dbaccess/source/ui/dlg/dsselect.hxx b/dbaccess/source/ui/dlg/dsselect.hxx
index d2ac059827e9..93509a044d45 100644
--- a/dbaccess/source/ui/dlg/dsselect.hxx
+++ b/dbaccess/source/ui/dlg/dsselect.hxx
@@ -75,7 +75,7 @@ public:
inline String GetSelected() const { return m_aDatasource.GetSelectEntry();}
void Select( const String& _rEntry ) { m_aDatasource.SelectEntry(_rEntry); }
- virtual BOOL Close();
+ virtual sal_Bool Close();
protected:
DECL_LINK( ListDblClickHdl, ListBox * );
diff --git a/dbaccess/source/ui/dlg/generalpage.cxx b/dbaccess/source/ui/dlg/generalpage.cxx
index 50658fb7811d..e54d5ea55719 100644
--- a/dbaccess/source/ui/dlg/generalpage.cxx
+++ b/dbaccess/source/ui/dlg/generalpage.cxx
@@ -503,7 +503,7 @@ namespace dbaui
}
//-------------------------------------------------------------------------
- BOOL OGeneralPage::FillItemSet(SfxItemSet& _rCoreAttrs)
+ sal_Bool OGeneralPage::FillItemSet(SfxItemSet& _rCoreAttrs)
{
sal_Bool bChangedSomething = sal_False;
@@ -528,7 +528,7 @@ namespace dbaui
if ( bCommitTypeSelection )
{
- USHORT nEntry = m_pDatasourceType->GetSelectEntryPos();
+ sal_uInt16 nEntry = m_pDatasourceType->GetSelectEntryPos();
::rtl::OUString sURLPrefix = m_aURLPrefixes[nEntry];
if (m_DBWizardMode)
{
diff --git a/dbaccess/source/ui/dlg/generalpage.hxx b/dbaccess/source/ui/dlg/generalpage.hxx
index efd1e326d5cf..729e38eb7dff 100644
--- a/dbaccess/source/ui/dlg/generalpage.hxx
+++ b/dbaccess/source/ui/dlg/generalpage.hxx
@@ -141,7 +141,7 @@ namespace dbaui
protected:
// SfxTabPage overridables
- virtual BOOL FillItemSet(SfxItemSet& _rCoreAttrs);
+ virtual sal_Bool FillItemSet(SfxItemSet& _rCoreAttrs);
virtual void Reset(const SfxItemSet& _rCoreAttrs);
virtual void implInitControls(const SfxItemSet& _rSet, sal_Bool _bSaveValue);
diff --git a/dbaccess/source/ui/dlg/queryorder.cxx b/dbaccess/source/ui/dlg/queryorder.cxx
index 45dea3837d00..3a735025ea80 100644
--- a/dbaccess/source/ui/dlg/queryorder.cxx
+++ b/dbaccess/source/ui/dlg/queryorder.cxx
@@ -114,7 +114,7 @@ DlgOrderCrit::DlgOrderCrit( Window * pParent,
AllSettings aSettings( GetSettings() );
StyleSettings aStyle( aSettings.GetStyleSettings() );
- aStyle.SetAutoMnemonic( FALSE );
+ aStyle.SetAutoMnemonic( sal_False );
aSettings.SetStyleSettings( aStyle );
SetSettings( aSettings );
diff --git a/dbaccess/source/ui/dlg/sqlmessage.cxx b/dbaccess/source/ui/dlg/sqlmessage.cxx
index f19f65313a0d..5114587c0af6 100644
--- a/dbaccess/source/ui/dlg/sqlmessage.cxx
+++ b/dbaccess/source/ui/dlg/sqlmessage.cxx
@@ -121,14 +121,14 @@ namespace
class ImageProvider : public IImageProvider
{
private:
- USHORT m_defaultImageID;
- USHORT m_highContrastImageID;
+ sal_uInt16 m_defaultImageID;
+ sal_uInt16 m_highContrastImageID;
mutable Image m_defaultImage;
mutable Image m_highContrastImage;
public:
- ImageProvider( USHORT _defaultImageID, USHORT _highContrastImageID )
+ ImageProvider( sal_uInt16 _defaultImageID, sal_uInt16 _highContrastImageID )
:m_defaultImageID( _defaultImageID )
,m_highContrastImageID( _highContrastImageID )
{
@@ -155,7 +155,7 @@ namespace
private:
String m_label;
public:
- LabelProvider( USHORT _labelResourceID )
+ LabelProvider( sal_uInt16 _labelResourceID )
:m_label( ModuleRes( _labelResourceID ) )
{
}
@@ -185,8 +185,8 @@ namespace
::boost::shared_ptr< IImageProvider > getImageProvider( SQLExceptionInfo::TYPE _eType ) const
{
::boost::shared_ptr< IImageProvider >* ppProvider( &m_pErrorImage );
- USHORT nNormalImageID( BMP_EXCEPTION_ERROR );
- USHORT nHCImageID( BMP_EXCEPTION_ERROR_SCH );
+ sal_uInt16 nNormalImageID( BMP_EXCEPTION_ERROR );
+ sal_uInt16 nHCImageID( BMP_EXCEPTION_ERROR_SCH );
switch ( _eType )
{
@@ -214,7 +214,7 @@ namespace
::boost::shared_ptr< ILabelProvider > getLabelProvider( SQLExceptionInfo::TYPE _eType, bool _bSubLabel ) const
{
::boost::shared_ptr< ILabelProvider >* ppProvider( &m_pErrorLabel );
- USHORT nLabelID( STR_EXCEPTION_ERROR );
+ sal_uInt16 nLabelID( STR_EXCEPTION_ERROR );
switch ( _eType )
{
@@ -516,7 +516,7 @@ namespace
void lcl_addButton( ButtonDialog& _rDialog, StandardButtonType _eType, bool _bDefault )
{
- USHORT nButtonID = 0;
+ sal_uInt16 nButtonID = 0;
switch ( _eType )
{
case BUTTON_YES: nButtonID = BUTTONID_YES; break;
diff --git a/dbaccess/source/ui/dlg/tablespage.cxx b/dbaccess/source/ui/dlg/tablespage.cxx
index 6523e0f17cd6..a53bd9722b58 100644
--- a/dbaccess/source/ui/dlg/tablespage.cxx
+++ b/dbaccess/source/ui/dlg/tablespage.cxx
@@ -647,7 +647,7 @@ DBG_NAME(OTableSubscriptionPage)
}
//------------------------------------------------------------------------
- BOOL OTableSubscriptionPage::FillItemSet( SfxItemSet& _rCoreAttrs )
+ sal_Bool OTableSubscriptionPage::FillItemSet( SfxItemSet& _rCoreAttrs )
{
sal_Bool bValid, bReadonly;
getFlags(_rCoreAttrs, bValid, bReadonly);
diff --git a/dbaccess/source/ui/dlg/tablespage.hxx b/dbaccess/source/ui/dlg/tablespage.hxx
index 0e7f72bd5c93..0591eb396ae3 100644
--- a/dbaccess/source/ui/dlg/tablespage.hxx
+++ b/dbaccess/source/ui/dlg/tablespage.hxx
@@ -81,7 +81,7 @@ namespace dbaui
OTableSubscriptionDialog* m_pTablesDlg;
public:
- virtual BOOL FillItemSet(SfxItemSet& _rCoreAttrs);
+ virtual sal_Bool FillItemSet(SfxItemSet& _rCoreAttrs);
virtual int DeactivatePage(SfxItemSet* _pSet);
using OGenericAdministrationPage::DeactivatePage;
@@ -118,7 +118,7 @@ namespace dbaui
::com::sun::star::uno::Sequence< ::rtl::OUString > collectDetailedSelection() const;
/// (un)check all entries
- void CheckAll( BOOL bCheck = sal_True );
+ void CheckAll( sal_Bool bCheck = sal_True );
virtual void implInitControls(const SfxItemSet& _rSet, sal_Bool _bSaveValue);
diff --git a/dbaccess/source/ui/dlg/RelationDlg.cxx b/dbaccess/source/ui/dlg/RelationDlg.cxx
index d24a1d87dee1..f4e924f4edd3 100644
--- a/dbaccess/source/ui/dlg/RelationDlg.cxx
+++ b/dbaccess/source/ui/dlg/RelationDlg.cxx
@@ -97,7 +97,7 @@ DBG_NAME(ORelationDialog)
//========================================================================
ORelationDialog::ORelationDialog( OJoinTableView* pParent,
const TTableConnectionData::value_type& pConnectionData,
- BOOL bAllowTableSelect )
+ sal_Bool bAllowTableSelect )
:ModalDialog( pParent, ModuleRes(DLG_REL_PROPERTIES) )
,m_pTableMap(pParent->GetTabWinMap())
@@ -117,7 +117,7 @@ ORelationDialog::ORelationDialog( OJoinTableView* pParent,
,aPB_HELP( this, ModuleRes( PB_HELP ) )
,m_pOrigConnData( pConnectionData )
- ,m_bTriedOneUpdate(FALSE)
+ ,m_bTriedOneUpdate(sal_False)
{
DBG_CTOR(ORelationDialog,NULL);
@@ -155,18 +155,18 @@ void ORelationDialog::Init(const TTableConnectionData::value_type& _pConnectionD
{
case KeyRule::NO_ACTION:
case KeyRule::RESTRICT:
- aRB_NoCascUpd.Check( TRUE );
+ aRB_NoCascUpd.Check( sal_True );
break;
case KeyRule::CASCADE:
- aRB_CascUpd.Check( TRUE );
+ aRB_CascUpd.Check( sal_True );
break;
case KeyRule::SET_NULL:
- aRB_CascUpdNull.Check( TRUE );
+ aRB_CascUpdNull.Check( sal_True );
break;
case KeyRule::SET_DEFAULT:
- aRB_CascUpdDefault.Check( TRUE );
+ aRB_CascUpdDefault.Check( sal_True );
break;
}
@@ -175,18 +175,18 @@ void ORelationDialog::Init(const TTableConnectionData::value_type& _pConnectionD
{
case KeyRule::NO_ACTION:
case KeyRule::RESTRICT:
- aRB_NoCascDel.Check( TRUE );
+ aRB_NoCascDel.Check( sal_True );
break;
case KeyRule::CASCADE:
- aRB_CascDel.Check( TRUE );
+ aRB_CascDel.Check( sal_True );
break;
case KeyRule::SET_NULL:
- aRB_CascDelNull.Check( TRUE );
+ aRB_CascDelNull.Check( sal_True );
break;
case KeyRule::SET_DEFAULT:
- aRB_CascDelDefault.Check( TRUE );
+ aRB_CascDelDefault.Check( sal_True );
break;
}
}
@@ -205,7 +205,7 @@ IMPL_LINK( ORelationDialog, OKClickHdl, Button*, /*pButton*/ )
{
//////////////////////////////////////////////////////////////////////
// RadioButtons auslesen
- UINT16 nAttrib = 0;
+ sal_uInt16 nAttrib = 0;
// Delete Rules
if( aRB_NoCascDel.IsChecked() )
@@ -234,7 +234,7 @@ IMPL_LINK( ORelationDialog, OKClickHdl, Button*, /*pButton*/ )
m_pTableControl->SaveModified();
//// wenn die ComboBoxen fuer die Tabellenauswahl enabled sind (Constructor mit bAllowTableSelect==TRUE), dann muss ich in die
//// Connection auch die Tabellennamen stecken
//m_pConnData->SetSourceWinName(m_pTableControl->getSourceWinName());
//m_pConnData->SetDestWinName(m_pTableControl->getDestWinName());
@@ -261,7 +261,7 @@ IMPL_LINK( ORelationDialog, OKClickHdl, Button*, /*pButton*/ )
DBG_UNHANDLED_EXCEPTION();
}
- m_bTriedOneUpdate = TRUE;
+ m_bTriedOneUpdate = sal_True;
// this means that the original connection may be lost (if m_pConnData was not a newly created but an
// existent conn to be modified), which we reflect by returning RET_NO (see ::Execute)
@@ -234,7 +234,7 @@ IMPL_LINK( ORelationDialog, OKClickHdl, Button*, /*pButton*/ )
m_pTableControl->SaveModified();
- //// wenn die ComboBoxen fuer die Tabellenauswahl enabled sind (Constructor mit bAllowTableSelect==TRUE), dann muss ich in die
+ //// wenn die ComboBoxen fuer die Tabellenauswahl enabled sind (Constructor mit bAllowTableSelect==sal_True), dann muss ich in die
//// Connection auch die Tabellennamen stecken
//m_pConnData->SetSourceWinName(m_pTableControl->getSourceWinName());
diff --git a/dbaccess/source/ui/dlg/advancedsettings.cxx b/dbaccess/source/ui/dlg/advancedsettings.cxx
index 1516c735f009..98b819b2f38c 100644
--- a/dbaccess/source/ui/dlg/advancedsettings.cxx
+++ b/dbaccess/source/ui/dlg/advancedsettings.cxx
@@ -69,9 +69,9 @@ namespace dbaui
struct BooleanSettingDesc
{
CheckBox** ppControl; // the dialog's control which displays this setting
- USHORT nControlResId; // the resource ID to load the control from
- USHORT nItemId; // the ID of the item (in an SfxItemSet) which corresponds to this setting
- bool bInvertedDisplay; // true if and only if the checkbox is checked when the item is FALSE, and vice versa
+ sal_uInt16 nControlResId; // the resource ID to load the control from
+ sal_uInt16 nItemId; // the ID of the item (in an SfxItemSet) which corresponds to this setting
+ bool bInvertedDisplay; // true if and only if the checkbox is checked when the item is sal_False, and vice versa
};
//========================================================================
@@ -113,17 +113,17 @@ namespace dbaui
++setting
)
{
- USHORT nItemId = setting->nItemId;
+ sal_uInt16 nItemId = setting->nItemId;
if ( rFeatures.has( nItemId ) )
{
- USHORT nResourceId = setting->nControlResId;
+ sal_uInt16 nResourceId = setting->nControlResId;
(*setting->ppControl) = new CheckBox( this, ModuleRes( nResourceId ) );
(*setting->ppControl)->SetClickHdl( getControlModifiedLink() );
// check whether this must be a tristate check box
const SfxPoolItem& rItem = _rCoreAttrs.Get( nItemId );
if ( rItem.ISA( OptionalBoolItem ) )
- (*setting->ppControl)->EnableTriState( TRUE );
+ (*setting->ppControl)->EnableTriState( sal_True );
}
}
@@ -318,7 +318,7 @@ namespace dbaui
}
else
{
- BOOL bValue = *aValue;
+ sal_Bool bValue = *aValue;
if ( setting->bInvertedDisplay )
bValue = !bValue;
(*setting->ppControl)->Check( bValue );
@@ -329,7 +329,7 @@ namespace dbaui
if ( m_bHasBooleanComparisonMode )
{
SFX_ITEMSET_GET( _rSet, pBooleanComparison, SfxInt32Item, DSID_BOOLEANCOMPARISON, sal_True );
- m_pBooleanComparisonMode->SelectEntryPos( static_cast< USHORT >( pBooleanComparison->GetValue() ) );
+ m_pBooleanComparisonMode->SelectEntryPos( static_cast< sal_uInt16 >( pBooleanComparison->GetValue() ) );
}
if ( m_bHasMaxRowScan )
@@ -522,7 +522,7 @@ namespace dbaui
}
//-------------------------------------------------------------------------
- void AdvancedSettingsDialog::PageCreated(USHORT _nId, SfxTabPage& _rPage)
+ void AdvancedSettingsDialog::PageCreated(sal_uInt16 _nId, SfxTabPage& _rPage)
{
// register ourself as modified listener
static_cast<OGenericAdministrationPage&>(_rPage).SetServiceFactory(m_pImpl->getORB());